ProcessService class

Constructors

ProcessService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runBuildRunner(String projectPath) Future<void>
Runs dart run build_runner build in the target project.
runCommand(String executable, List<String> arguments, {String? workingDirectory, bool showOutput = false}) Future<ProcessResult>
Runs a shell command and returns the results. Throws a CliException if the process returns a non-zero exit code.
runFlutterCreate({required String projectName, required String outputDirectory}) Future<void>
Runs flutter create to initialize a new project.
runFlutterPubGet(String projectPath) Future<void>
Runs flutter pub get in the target project.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited