TemplateService class

Constructors

TemplateService(FileService _fileService)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getTemplatePath() Future<String>
Resolves the base template directory path.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renderTemplate({required String templateSubPath, required String targetPath, required Map<String, String> replacements}) Future<void>
Recursively copies a template folder/file to a target directory, interpolating placeholders.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited