WizardHelper class

Constructors

WizardHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

promptConfirm(String message, {bool defaultValue = true}) bool
Prompts the user for a Yes/No question.
promptMultiSelect<T>({required String message, required List<T> options, required String labelProvider(T), List<T>? defaultSelections}) List<T>
Prompts the user to select multiple options using spacebar & arrow keys.
promptSelect<T>({required String message, required List<T> options, required String labelProvider(T), int defaultIndex = 0}) → T
Prompts the user to select one option using arrow keys.
promptString(String message, {String? defaultValue, bool validator(String)?}) String
Prompts the user for a text string.