usage property
Generates a string displaying usage information for this command.
This includes usage for the command's arguments as well as a list of subcommands, if there are any.
Implementation
@override
String get usage => '''
Usage: flutter_init_cli create [options]
Options:
-n, --name The name of the Flutter project to generate.
-h, --help Print this usage information.
Examples:
# Start the interactive project wizard (recommended)
flutter_init_cli create
# Start the wizard with a pre-filled project name
flutter_init_cli create --name my_awesome_app
''';