FileService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyDirectory(
String sourceDir, String destinationDir) → void - Recursively copies a directory's contents.
-
copyFile(
String srcPath, String destPath) → File - Copies a file from source to destination.
-
createDir(
String path) → Directory - Ensures that a directory exists, creating it if it doesn't.
-
delete(
String path) → void - Deletes a file or directory if it exists.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readFile(
String path) → String - Reads a file's content as a string.
-
replaceInFile(
String path, Map< String, String> replacements) → void - Replaces strings in a file's content.
-
toString(
) → String -
A string representation of this object.
inherited
-
writeFile(
String path, String content) → File - Writes string content to a file, creating any parent folders if necessary.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited