YamlService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addAssets(
String pubspecPath, List< String> assetPaths) → void - Adds a list of assets to the pubspec.yaml under the flutter: assets: section.
-
addDependency(
String pubspecPath, String name, String version, {bool isDev = false}) → void - Adds a dependency to pubspec.yaml.
-
addFont(
String pubspecPath, String fontFamily, List< String> fontPaths) → void - Adds a font configuration under the flutter: fonts: section.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited