CaseHelper class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
toCamelCase(
String text) → String - Converts string to camelCase.
-
toPascalCase(
String text) → String - Converts string to PascalCase.
-
toSnakeCase(
String text) → String - Converts string to snake_case.
-
toUpperCase(
String text) → String - Converts string to UPPERCASE_SNAKE_CASE.